pub unconstrained fn get_last_call_offchain_effects( ) -> BoundedVec<BoundedVec<Field, 17>, 64>
Returns the raw offchain effect payloads emitted by the last top-level call into TXE. Each effect is a variable-length field array (e.g. offchain messages have a different size than authwit authorization requests).
Returns the raw offchain effect payloads emitted by the last top-level call into TXE. Each effect is a variable-length field array (e.g. offchain messages have a different size than authwit authorization requests).