Struct TXECallContext
pub struct TXECallContext {
pub tx_hash: Option<Field>,
pub anchor_block_timestamp: u64,
}
Fields
Tx hash of the top-level call, or None if the call was tx-less (execute_utility, context
setters, etc.).
anchor_block_timestamp: u64Anchor block timestamp captured at the start of the call. Note: this is not the timestamp of the block where a transaction produced by this call is included, which does not exist at the moment TXE runs the call.
The context of the last top-level call into TXE, as captured by the call executor. Refreshed on every top-level call.